#include<iostream>
#include<vector>
#include<deque>
#include<numeric>
using namespace std;


struct Stree {
	struct Node {
		long long val = 0;
		Node* lch = 0, *rch = 0;
		
		void update() {
			val = lch->val + rch->val;
		}
	};
	
	int n;
	deque<Node> nodes;
	
	Node* construct(vector<int> a) {
		n = 1;
		while(n < (int)a.size())
			n *= 2;
		nodes.resize(2*n);
		
		for(int i=0;i<n;i++)
			nodes[n+i].val = (i < (int)a.size() ? a[i] : 0);
		
		for(int i=n-1;i>0;i--) {
			nodes[i].lch = &nodes[2*i];
			nodes[i].rch = &nodes[2*i+1];
			nodes[i].update();
		}
		
		return &nodes[1];
	}
	
	Node* set(Node* cur, int pos, int nval, int lb = 0, int rb = -1) {
		if(rb == -1)
			rb = n;
		
		nodes.push_back(*cur);
		cur = &nodes.back();
		
		if(rb - lb == 1) {
			cur->val = nval;
			return cur;
		}
		
		int mid = (lb + rb) / 2;
		if(pos < mid)
			cur->lch = set(cur->lch, pos, nval, lb, mid);
		else
			cur->rch = set(cur->rch, pos, nval, mid, rb);
		cur->update();
		return cur;
	}
	
	long long get(Node* cur, int l, int r, int lb = 0, int rb = -1) {
		if(rb == -1)
			rb = n;
		
		if(l <= lb && rb <= r)
			return cur->val;
		
		vector<long long> returned;
		int mid = (lb + rb) / 2;
		
		if(l < mid)
			returned.push_back(get(cur->lch, l, r, lb, mid) );
		if(mid < r)
			returned.push_back(get(cur->rch, l, r, mid, rb) );
		return accumulate(returned.begin(), returned.end(), 0LL );
	}
	
};


int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	
	int n, m, q;
	Stree st;
	vector<Stree::Node*> roots;
	
	cin >> n;
	{
		vector<int> a(n);
		for(int i=0;i<n;i++)
			cin >> a[i];
		
		roots.push_back(st.construct(a) );
	}
	
	cin >> m;
	
	for(int i=0;i<m;i++) {
		int pos, val;
		cin >> pos >> val;
		roots.push_back(st.set(roots.back(), pos-1, val));
	}
	
	cin >> q;
	
	for(int i=0;i<q;i++) {
		int t, l, r;
		cin >> t >> l >> r;
		
		cout << st.get(roots[t], l-1, r) << endl;
	}
	
	return 0;
}